==> pnetlib-0.5.10.tar.gz: pnetlib-0.5.10/System.Drawing.Win32/DrawingFont.cs <==
/*
 * DrawingFont.cs - Implementation of fonts for System.Drawing.Win32.
 * Copyright (C) 2003  Neil Cawse.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

namespace System.Drawing.Toolkit
{

using System;
using System.Runtime.InteropServices;

internal class DrawingFont : IToolkitFont
{
	// Internal state.
	internal System.Drawing.Font properties;
	private IToolkit toolkit;
	internal IntPtr hFont;
	
	public DrawingFont(IToolkit toolkit, System.Drawing.Font properties)
			{
				this.toolkit = toolkit;
				this.properties = properties;
				CreateFont();
			}

	// Select this font into a graphics object.
	public void Select(IToolkitGraphics graphics)
			{
				(graphics as DrawingGraphics).selectedFont = this;
			}

	// Dispose of this font.
	public void Dispose()
			{
				Win32.Api.DeleteObject(hFont);
				hFont = IntPtr.Zero;
			}

	// Get the raw HFONT for this toolkit font.  IntPtr.Zero if none.
	public IntPtr GetHfont()
			{
				return hFont;
			}

	// Get the LOGFONT information for this toolkit font.
	public void ToLogFont(Object lf, IToolkitGraphics graphics)
			{
				Win32.Api.LOGFONT logFont;
				Win32.Api.GetObject( hFont, Marshal.SizeOf(typeof(Win32.Api.LOGFONT)), out logFont);
				lf = logFont;
			}

	private void CreateFont()
	{
		Win32.Api.LOGFONT lf = new Win32.Api.LOGFONT();
		lf.lfHeight=(int)-properties.SizeInPoints;
		lf.lfFaceName=properties.FontFamily.Name;
		switch (properties.Style)
		{
			case(FontStyle.Bold):
				lf.lfWeight = 600;
				break;
			case(FontStyle.Italic):
				lf.lfItalic = 1;
				break;
			case(FontStyle.Strikeout):
				lf.lfStrikeout = 1;
				break;
			case(FontStyle.Underline):
				lf.lfUnderline = 1;
				break;
		}
			
		lf.lfQuality = Win32.Api.FontQuality.CLEARTYPE_QUALITY;
		hFont = Win32.Api.CreateFontIndirectA(ref lf);
	}

}; // class DrawingFont

}; // namespace System.Drawing.Toolkit

==> pnetlib-0.5.12.tar.gz: pnetlib-0.5.12/System.Drawing.Win32/DrawingFont.cs <==
/*
 * DrawingFont.cs - Implementation of fonts for System.Drawing.Win32.
 * Copyright (C) 2003  Neil Cawse.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

namespace System.Drawing.Toolkit
{

using System;
using System.Runtime.InteropServices;

internal class DrawingFont : IToolkitFont
{
	// Internal state.
	internal System.Drawing.Font properties;
	private float dpi;
	private IToolkit toolkit;
	internal IntPtr hFont;
	
	public DrawingFont(IToolkit toolkit, System.Drawing.Font properties, float dpi)
			{
				this.toolkit = toolkit;
				this.properties = properties;
				this.dpi = dpi;
				CreateFont();
			}

	// Select this font into a graphics object.
	public void Select(IToolkitGraphics graphics)
			{
				Win32.Api.SelectObject((graphics as DrawingGraphics).hdc, hFont);
				(graphics as DrawingGraphics).selectedFont = this;
			}

	// Dispose of this font.
	public void Dispose()
			{
				Win32.Api.DeleteObject(hFont);
				hFont = IntPtr.Zero;
			}

	// Get the raw HFONT for this toolkit font.  IntPtr.Zero if none.
	public IntPtr GetHfont()
			{
				return hFont;
			}

	// Get the LOGFONT information for this toolkit font.
	public void ToLogFont(Object lf, IToolkitGraphics graphics)
			{
				Win32.Api.LOGFONT logFont;
				Win32.Api.GetObject( hFont, Marshal.SizeOf(typeof(Win32.Api.LOGFONT)), out logFont);
				lf = logFont;
			}

	private void CreateFont()
	{
		properties.FontFamily.GetEmHeight(properties.Style);
		Win32.Api.LOGFONT lf = new Win32.Api.LOGFONT();
		lf.lfHeight=(int)(-properties.SizeInPoints*dpi/72);
		lf.lfFaceName=properties.FontFamily.Name;
		switch (properties.Style)
		{
			case(FontStyle.Bold):
				lf.lfWeight = 600;
				break;
			case(FontStyle.Italic):
				lf.lfItalic = 1;
				break;
			case(FontStyle.Strikeout):
				lf.lfStrikeout = 1;
				break;
			case(FontStyle.Underline):
				lf.lfUnderline = 1;
				break;
		}
			
		lf.lfQuality = Win32.Api.FontQuality.CLEARTYPE_QUALITY;
		hFont = Win32.Api.CreateFontIndirectA(ref lf);
	}

}; // class DrawingFont

}; // namespace System.Drawing.Toolkit
